@@ -41,11 +41,10 @@ class LibreGaming:
         contents = urllib.request.urlopen('https://pypi.org/pypi/'+pkgName+'/json').read()
         data = json.loads(contents)
         latest_version = data['info']['version']
-        if latest_version != current_version:
-            self.whoami(True)
+        if current_version != latest_version:
             update = input("Your LibreGaming version is old, do you want to update?[Y/n]: ")
             if update.upper() == "Y" or update.upper() == "YES":
-                subprocess.run(["pip", "install", "LibreGaming", "-U"])
+                subprocess.run(["su", "-", "root", "-c" + "pip install LibreGaming -U"])
             else:
                 print("Declined update!\n")
         else:
@@ -53,17 +52,17 @@ class LibreGaming:
 
     # Gets the package manager by running $(command -v dnf)
     def getPackageManager(self):
-        if subprocess.getoutput("$(command -v dnf)"):
+        if subprocess.getoutput("command -v dnf"):
             self.PackageManager =  "dnf"
-        elif subprocess.getoutput("$(command -v yay)"):
+        elif subprocess.getoutput("command -v yay"):
             self.PackageManager =  "yay"
-        elif subprocess.getoutput("$(command -v paru)"):
+        elif subprocess.getoutput("command -v paru"):
             self.PackageManager =  "paru"
-        elif subprocess.getoutput("$(command -v pacman)"):
+        elif subprocess.getoutput("command -v pacman"):
             self.PackageManager =  "pacman"
-        elif subprocess.getoutput("$(command -v apt)"):
+        elif subprocess.getoutput("command -v apt"):
             self.PackageManager =  "apt"
-        elif subprocess.getoutput("$(command -v zypper)"):
+        elif subprocess.getoutput("command -v zypper"):
             self.PackageManager =  "zypper"
         else:
             print("Could not know your distro based on your Package Manager!")
